AGW Logo

svn SVN Revision 69086 For supertooltip

This file contains the SVN revision history for supertooltip, at revision 69086.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 19:15:31 UTC
  • Committer: AG
  • File Size: 46076 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

  • Fixed bug #13437 for SuperToolTip;
  • Fixed bug #13477 for UltimateListCtrl.

svn_diff Diff To Previous Version (68881)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/supertooltip.py       2011/08/25 16:40:17     68881
+++ wxPython/3rdParty/AGW/agw/supertooltip.py       2011/09/14 19:39:08     69086
@@ -2,7 +2,7 @@
# SUPERTOOLTIP wxPython IMPLEMENTATION
#
# Andrea Gavana, @ 07 October 2008
# Latest Revision: 17 Aug 2011, 15.00 GMT
#
#
# TODO List
@@ -117,7 +117,7 @@

L{SuperToolTip} is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 17 Aug 2011, 15.00 GMT
+Latest Revision: Andrea Gavana @ 14 Sep 2011, 21.00 GMT

Version 0.4

@@ -726,6 +726,21 @@
maxHeight += toAdd
self.SetSize((maxWidth, maxHeight))

+    def CalculateBestPosition(self,widget):
+        screen = wx.ClientDisplayRect()[2:]
+        left,top = widget.ClientToScreenXY(0,0)
+        right,bottom = widget.ClientToScreenXY(*widget.GetClientRect()[2:])
+        size = self.GetSize()
+        if right+size[0]>screen[0]:
+            xpos = left-size[0]
+        else:
+            xpos = right
+        if bottom+size[1]>screen[1]:
+            ypos = top-size[1]
+        else:
+            ypos = bottom
+        self.SetPosition((xpos,ypos))
+

# Handle Mac and Windows/GTK differences...

@@ -939,7 +954,7 @@
tip = ToolTipWindow(self._widget, self)
self._superToolTip = tip
self._superToolTip.CalculateBestSize()
-        self._superToolTip.SetPosition(wx.GetMousePosition())
+        self._superToolTip.CalculateBestPosition(self._widget)
self._superToolTip.DropShadow(self.GetDropShadow())

if self.GetUseFade():
@@ -974,7 +989,7 @@
tip = ToolTipWindow(self._widget, self)
self._superToolTip = tip
self._superToolTip.CalculateBestSize()
-        self._superToolTip.SetPosition(wx.GetMousePosition())
+        self._superToolTip.CalculateBestPosition(self._widget)
self._superToolTip.DropShadow(self.GetDropShadow())

# need to stop this, otherwise we get into trouble when leaving the window
@@ -2,7 +2,7 @@
#
# Andrea Gavana, @ 07 October 2008
-# Latest Revision: 17 Aug 2011, 15.00 GMT
+# Latest Revision: 14 Sep 2011, 21.00 GMT
#
#
Tree

Table Of Contents

Previous topic

SVN Revision 68881 For supertooltip

Next topic

thumbnailctrl